## 1.7.0.0 (2023-07-19)

[stubsabot] Bump tree-sitter-languages to 1.7.* (#10474)

Release: https://pypi.org/pypi/tree-sitter-languages/1.7.0
Homepage: https://github.com/grantjenks/py-tree-sitter-languages
Diff: https://github.com/grantjenks/py-tree-sitter-languages/compare/v1.6.1...v1.7.0

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `tree_sitter_languages/__init__.py`.
 - Total lines of Python code added: 3.
 - Total lines of Python code deleted: 1.

## 1.6.0.0 (2023-06-27)

[stubsabot] Bump tree-sitter-languages to 1.6.* (#10364)

Release: https://pypi.org/pypi/tree-sitter-languages/1.6.1
Homepage: https://github.com/grantjenks/py-tree-sitter-languages
Diff: https://github.com/grantjenks/py-tree-sitter-languages/compare/v1.5.0...v1.6.1

Stubsabot analysis of the diff between the two releases:
 - 0 public Python files have been added.
 - 0 files included in typeshed's stubs have been deleted.
 - 1 file included in typeshed's stubs has been modified or renamed: `tree_sitter_languages/__init__.py`.
 - Total lines of Python code added: 68.
 - Total lines of Python code deleted: 5.

## 1.5.0.2 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.5.0.1 (2023-01-13)

Allowlist-only fixes for stubtest on Windows (#9522)

## 1.5.0 (2022-09-16)

[stubsabot] Bump tree-sitter-languages to 1.5.* (#8750)

Release: https://pypi.org/project/tree-sitter-languages/1.5.0/
Homepage: https://github.com/grantjenks/py-tree-sitter-languages
Diff: https://github.com/grantjenks/py-tree-sitter-languages/compare/v1.4.0...v1.5.0

## 1.4.0 (2022-08-26)

[stubsabot] Bump tree-sitter-languages to 1.4.* (#8623)

## 1.3.0 (2022-08-17)

Add stubs for tree-sitter-languages (#8548)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

